"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const folder_1 = require("../../../lib/analytics/app/folder");
const wavetemplate_1 = require("../../../lib/analytics/template/wavetemplate");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/analytics', 'app');
class Create extends command_1.SfdxCommand {
    async run() {
        this.folder = new folder_1.default(this.org);
        const templateid = this.flags.templateid;
        let body;
        if (templateid) {
            this.template = new wavetemplate_1.default(this.org);
            await this.template.list(templateid);
            body = JSON.stringify({
                description: this.template.template.description,
                label: this.template.template.label,
                templateSourceId: templateid,
                assetIcon: '16.png',
                templateValues: {},
                name: this.template.template.name
            });
        }
        else {
            const path = this.flags.definitionfile.toString();
            body = await command_1.core.fs.readFile(path, 'utf8');
        }
        await this.folder.create(body);
        const waveAppId = this.folder.id;
        this.ux.log(messages.getMessage('createSuccess1', [waveAppId]));
        this.ux.log(messages.getMessage('createSuccess2', [waveAppId]));
        return waveAppId;
    }
}
Create.description = messages.getMessage('createCommandDescription');
Create.longDescription = messages.getMessage('createCommandLongDescription');
Create.examples = [
    '$ sfdx analytics:app:create -t templateid',
    '$ sfdx analytics:app:create -f path_to_json_file'
];
Create.flagsConfig = {
    templateid: {
        char: 't',
        type: 'text',
        description: messages.getMessage('templateidFlagDescription'),
        longDescription: messages.getMessage('templateidFlagLongDescription')
    },
    definitionfile: {
        char: 'f',
        type: 'filepath',
        description: messages.getMessage('appDefinitionFileFlagDescription'),
        longDescription: messages.getMessage('appDefinitionFileFlagLongDescription')
    }
};
// Comment this out if your command does not require an org username
Create.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Create.requiresProject = true;
exports.default = Create;
//# sourceMappingURL=create.js.map