"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const cli_ux_1 = require("cli-ux");
const folder_1 = require("../../../lib/analytics/app/folder");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/analytics', 'app');
class Delete extends command_1.SfdxCommand {
    async run() {
        if (this.flags.noprompt) {
            await this.executeCommand();
        }
        else {
            const answer = await cli_ux_1.cli.prompt(messages.getMessage('confirmDeleteYesNo'));
            if (answer.toUpperCase() === 'YES' || answer.toUpperCase() === 'Y') {
                await this.executeCommand();
            }
        }
        return this.folder.id;
    }
    async executeCommand() {
        this.folder = new folder_1.default(this.org);
        await this.folder.deleteFolder(this.flags.folderid);
        this.ux.log(messages.getMessage('deleteAppSuccess', [this.flags.folderid]));
    }
}
Delete.description = messages.getMessage('deleteCommandDescription');
Delete.longDescription = messages.getMessage('deleteCommandLongDescription');
Delete.examples = [
    '$ sfdx analytics:app:delete -f folderid'
];
Delete.tableColumnData = null;
Delete.flagsConfig = {
    folderid: {
        char: 'f',
        type: 'id',
        required: true,
        description: messages.getMessage('folderidFlagDescription'),
        longDescription: messages.getMessage('folderidFlagLongDescription')
    },
    noprompt: {
        char: 'p',
        type: 'boolean',
        description: messages.getMessage('nopromptFlagDescription'),
        longDescription: messages.getMessage('nopromptFlagLongDescription')
    }
};
// Comment this out if your command does not require an org username
Delete.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Delete.requiresProject = true;
exports.default = Delete;
//# sourceMappingURL=delete.js.map