"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const path_1 = require("path");
const folder_1 = require("../../../lib/analytics/app/folder");
command_1.core.Messages.importMessagesDirectory(path_1.join(__dirname, '..', '..', '..', '..'));
const messages = command_1.core.Messages.loadMessages('@salesforce/analytics', 'app');
class List extends command_1.SfdxCommand {
    constructor() {
        super(...arguments);
        this.folders = [];
    }
    async run() {
        this.folder = new folder_1.default(this.org);
        const folderid = this.flags.folderid;
        await this.folder.list();
        this.folders = this.folder.folders.filter(folder => {
            if (folderid) {
                return (folder.id === folderid);
            }
            else {
                return true;
            }
        }).map(folder => ({
            name: folder.name,
            label: folder.label,
            folderid: folder.id,
            status: folder.applicationStatus,
            templateSourceId: folder.templateSourceId !== null ? folder.templateSourceId : null,
            namespace: folder.namespace
        }));
        if (this.folders.length > 0) {
            this.ux.styledHeader(messages.getMessage('appsFound', [this.folders.length]));
        }
        return this.folders;
    }
}
List.description = messages.getMessage('listCommandDescription');
List.longDescription = messages.getMessage('listCommandLongDescription');
List.examples = [
    '$ sfdx analytics:app:list --targetusername myOrg@example.com --targetdevhubusername my@org.com'
];
List.flagsConfig = {
    folderid: {
        char: 'f',
        description: messages.getMessage('folderidFlagDescription'),
        longDescription: messages.getMessage('folderidFlagLongDescription')
    }
};
// Comment this out if your command does not require an org username
List.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
// protected static requiresProject = true;
List.tableColumnData = ['name', 'label', 'folderid', 'status', 'templateSourceId', 'namespace'];
exports.default = List;
//# sourceMappingURL=list.js.map