"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const folder_1 = require("../../../lib/analytics/app/folder");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/analytics', 'app');
class Update extends command_1.SfdxCommand {
    async run() {
        this.folder = new folder_1.default(this.org);
        const pathJson = this.flags.definitionfile.toString();
        const body = await command_1.core.fs.readFile(pathJson, 'utf8');
        await this.folder.update(body, this.flags.folderid);
        // If error occurs here fails out in the update call and reports back, otherwise success
        const waveAppId = this.folder.id;
        this.ux.log(messages.getMessage('updateSuccess', [waveAppId]));
        return waveAppId;
    }
}
Update.description = messages.getMessage('updateCommandDescription');
Update.longDescription = messages.getMessage('updateCommandLongDescription');
Update.examples = [
    '$ sfdx analytics:app:update -i folderId -f path_to_json_file'
];
Update.flagsConfig = {
    definitionfile: {
        char: 'f',
        type: 'filepath',
        required: true,
        description: messages.getMessage('appUpdateFileFlagDescription'),
        longDescription: messages.getMessage('appUpdateFileFlagLongDescription')
    },
    folderid: {
        char: 'i',
        type: 'id',
        required: true,
        description: messages.getMessage('folderidFlagDescription'),
        longDescription: messages.getMessage('folderidFlagLongDescription')
    }
};
Update.requiresUsername = true;
Update.requiresProject = true;
exports.default = Update;
//# sourceMappingURL=update.js.map