"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const dashboard_1 = require("../../../lib/analytics/dashboard/dashboard");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/analytics', 'dashboard');
class List extends command_1.SfdxCommand {
    constructor() {
        super(...arguments);
        this.dashboards = [];
    }
    async run() {
        this.dashboard = new dashboard_1.default(this.org);
        await this.dashboard.list();
        this.dashboards = this.dashboard.dashboards.map(dashboard => ({
            dashboardid: dashboard.id,
            name: dashboard.name,
            namespace: dashboard.namespace,
            label: dashboard.label,
            folderid: dashboard.folder.id,
            foldername: dashboard.folder.name
        }));
        if (this.dashboards.length) {
            this.ux.styledHeader(messages.getMessage('dashboardsFound', [this.dashboards.length]));
        }
        return this.dashboards;
    }
}
List.description = messages.getMessage('listCommandDescription');
List.longDescription = messages.getMessage('listCommandLongDescription');
List.examples = [
    '$ sfdx analytics:dashboard:list --targetusername myorg@example.com --targetdevhubusername devhub@example.com'
];
List.flagsConfig = {};
// Comment this out if your command does not require an org username
List.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
List.requiresProject = true;
List.tableColumnData = ['dashboardid', 'name', 'namespace', 'label', 'folderid', 'foldername'];
exports.default = List;
//# sourceMappingURL=list.js.map