"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const cli_ux_1 = require("cli-ux");
const folder_1 = require("../../../lib/analytics/app/folder");
const wavetemplate_1 = require("../../../lib/analytics/template/wavetemplate");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/analytics', 'template');
class Delete extends command_1.SfdxCommand {
    constructor() {
        super(...arguments);
        this.foldersTodelete = [];
    }
    async run() {
        if (!this.flags.forcedelete || this.flags.noprompt) {
            await this.executeCommand();
        }
        else {
            const answer = await cli_ux_1.cli.prompt(messages.getMessage('confirmDeleteYesNo'));
            if (answer.toUpperCase() === 'YES' || answer.toUpperCase() === 'Y') {
                await this.executeCommand();
            }
        }
        return this.wavetemplate.id;
    }
    async executeCommand() {
        const templateid = this.flags.templateid;
        const forceDelete = this.flags.forcedelete;
        this.wavetemplate = new wavetemplate_1.default(this.org);
        // make sure we can find this template and if not let it error from the api
        await this.wavetemplate.list(templateid);
        if (forceDelete) {
            this.folder = new folder_1.default(this.org);
            await this.folder.list();
            this.folder.folders.filter(folder => folder.templateSourceId === templateid).map(folder => {
                // add folders found to delete to array
                this.foldersTodelete.push(folder.id);
            });
        }
        for (const folderid of this.foldersTodelete) {
            this.folder = new folder_1.default(this.org);
            await this.folder.deleteFolder(folderid);
            this.ux.log(messages.getMessage('deleteAppSuccess', [folderid]));
        }
        // Delete the template
        await this.wavetemplate.deleteTemplate(templateid);
        const waveTemplateId = this.wavetemplate.id;
        this.ux.log(messages.getMessage('deleteTemplateSuccess', [waveTemplateId]));
    }
}
Delete.description = messages.getMessage('deleteCommandDescription');
Delete.longDescription = messages.getMessage('deleteCommandLongDescription');
Delete.examples = [
    '$ sfdx analytics:template:delete -t templateid'
];
Delete.tableColumnData = null;
Delete.flagsConfig = {
    templateid: {
        char: 't',
        type: 'id',
        required: true,
        description: messages.getMessage('templateidFlagDescription'),
        longDescription: messages.getMessage('templateidFlagLongDescription')
    },
    forcedelete: {
        type: 'boolean',
        description: messages.getMessage('forceDeleteTemplateFlagDescription'),
        longDescription: messages.getMessage('forceDeleteTemplateFlagLongDescription')
    },
    noprompt: {
        char: 'p',
        type: 'boolean',
        description: messages.getMessage('nopromptFlagDescription'),
        longDescription: messages.getMessage('nopromptFlagLongDescription')
    }
};
// Comment this out if your command does not require an org username
Delete.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Delete.requiresProject = true;
exports.default = Delete;
//# sourceMappingURL=delete.js.map