"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const wavetemplate_1 = require("../../../lib/analytics/template/wavetemplate");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/analytics', 'template');
class List extends command_1.SfdxCommand {
    constructor() {
        super(...arguments);
        this.templates = [];
    }
    async run() {
        this.wavetemplate = new wavetemplate_1.default(this.org);
        await this.wavetemplate.list(null);
        this.templates = this.wavetemplate.templates.filter(template => {
            if (this.flags.includesalesforcetemplates) {
                return true;
            }
            else {
                return template.id.startsWith('0Nk');
            }
        }).map(template => ({
            name: template.name,
            templateid: template.id,
            folderid: (template.folderSource && template.folderSource.id) || null,
            namespace: template.namespace
        }));
        if (this.templates.length) {
            this.ux.styledHeader(messages.getMessage('templatesFound', [this.templates.length]));
        }
        return this.templates;
    }
}
List.description = messages.getMessage('listCommandDescription');
List.longDescription = messages.getMessage('listCommandLongDescription');
List.examples = [
    '$ sfdx analytics:template:list --targetusername myorg@example.com --targetdevhubusername devhub@example.com'
];
List.flagsConfig = {
    includesalesforcetemplates: {
        char: 'a',
        type: 'boolean',
        description: messages.getMessage('includeSalesforceTemplatesFlagDescription'),
        longDescription: messages.getMessage('includeSalesforceTemplatesFlagLongDescription')
    }
};
// Comment this out if your command does not require an org username
List.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
List.requiresProject = true;
List.tableColumnData = ['name', 'templateid', 'folderid', 'namespace'];
exports.default = List;
//# sourceMappingURL=list.js.map