"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const folder_1 = require("../../../lib/analytics/app/folder");
const wavetemplate_1 = require("../../../lib/analytics/template/wavetemplate");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/analytics', 'template');
class Update extends command_1.SfdxCommand {
    constructor() {
        super(...arguments);
        this.folders = [];
    }
    async run() {
        const templateid = this.flags.templateid;
        let folderid = this.flags.folderid;
        this.template = new wavetemplate_1.default(this.org);
        // no folder id provided, first see if we can find in on the folderSource of the template
        if (!folderid) {
            await this.template.list(templateid);
            folderid = this.template.template.folderSource ? this.template.template.folderSource.id : null;
        }
        // if we can't get the folder id from the folderSource, throw error and search for options to show in error message
        if (!folderid) {
            this.folder = new folder_1.default(this.org);
            // calling list first because PUT with a wrong id doens't fail correctly
            await this.folder.list();
            this.folders = this.folder.folders.filter(folder => folder.templateSourceId === templateid).map(folder => ({
                name: folder.name,
                label: folder.label,
                folderid: folder.id
            }));
            if (this.folders.length) {
                this.ux.styledHeader(messages.getMessage('errorNoFolderFound', [templateid]));
                this.ux.styledHeader(messages.getMessage('updateFolderIdNeeded2', [this.folders.length]));
                return this.folders;
            }
            else {
                this.ux.log(messages.getMessage('errorNoFolderFound', [templateid]));
                return;
            }
        }
        await this.template.update(folderid, templateid);
        this.ux.log(messages.getMessage('updateSuccess', [this.template.id]));
        return templateid;
    }
}
Update.description = messages.getMessage('updateCommandDescription');
Update.longDescription = messages.getMessage('updateCommandLongDescription');
Update.examples = [
    '$ sfdx analytics:template:update -t templateid -f folderid'
];
Update.flagsConfig = {
    templateid: {
        char: 't',
        type: 'id',
        required: true,
        description: messages.getMessage('templateidFlagDescription'),
        longDescription: messages.getMessage('templateidFlagLongDescription')
    },
    folderid: {
        char: 'f',
        type: 'id',
        description: messages.getMessage('folderidFlagDescription'),
        longDescription: messages.getMessage('folderidFlagLongDescription')
    }
};
// Comment this out if your command does not require an org username
Update.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Update.requiresProject = true;
Update.result = {
    tableColumnData: ['name', 'label', 'folderid'],
    display() {
        if (this.tableColumnData) {
            if (Array.isArray(this.data) && this.data.length) {
                this.ux.table(this.data, this.tableColumnData);
            }
        }
    }
};
exports.default = Update;
//# sourceMappingURL=update.js.map