"use strict";
/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
class Folder {
    constructor(organization) {
        this._folders = [];
        this.connection = organization.getConnection();
        this.foldersUrl = `${this.connection.baseUrl()}/wave/folders/`;
    }
    // The folders
    get folders() {
        return this._folders;
    }
    // The waveTemplate Id
    get id() {
        return this._id;
    }
    // The Folder Id
    get folder() {
        return this._folder;
    }
    async create(body) {
        const response = await this.connection.request({
            method: 'POST',
            url: this.foldersUrl,
            body
        });
        if (response) {
            this._id = response.id;
        }
        else {
            this.createError(response);
        }
    }
    async update(body, folderid) {
        const wtUrl = this.foldersUrl + folderid;
        const response = await this.connection.request({
            method: 'PATCH',
            url: wtUrl,
            body
        });
        if (response) {
            this._id = response.id;
        }
        else {
            this.createError(response);
        }
    }
    async list() {
        const response = await this.connection.request({
            method: 'GET',
            url: this.foldersUrl
        });
        if (response) {
            this._folders = response.folders;
        }
        else {
            this.createError(response);
        }
    }
    async deleteFolder(folderid) {
        const folderUrl = this.foldersUrl + folderid;
        await this.connection.request({
            method: 'DELETE',
            url: folderUrl
        });
        this._id = folderid;
    }
    createError(response) {
        // For Gacks, the error message is on response.body[0].message but for handled errors
        // the error message is on response.body.Errors[0].description.
        const errMessage = _.get(response, 'Errors[0].description') || _.get(response, '[0].message') || 'Unknown Error';
        throw new Error(errMessage);
    }
}
exports.default = Folder;
//# sourceMappingURL=folder.js.map