"use strict";
/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
class WaveTemplate {
    constructor(organization) {
        this._templates = [];
        this.connection = organization.getConnection();
        this.templatesUrl = `${this.connection.baseUrl()}/wave/templates/`;
    }
    // The waveTemplate Id
    get id() {
        return this._id;
    }
    // The waveTemplate Ids
    get templates() {
        return this._templates;
    }
    // The waveTemplate Id
    get template() {
        return this._template;
    }
    // Send request to wave template endpoint
    // combine this logic into a util method.
    async create(folderid) {
        const body = JSON.stringify({ folderSource: { id: folderid } });
        const response = await this.connection.request({
            method: 'POST',
            url: this.templatesUrl,
            body
        });
        if (response) {
            this._id = response.id;
        }
        else {
            this.createError(response);
        }
    }
    async update(folderid, templateid) {
        const body = JSON.stringify({ folderSource: { id: folderid } });
        const wtUrl = this.templatesUrl + templateid;
        const response = await this.connection.request({
            method: 'PUT',
            url: wtUrl,
            body
        });
        if (response) {
            this._id = response.id;
        }
        else {
            this.createError(response);
        }
    }
    async list(templateid) {
        let wtUrl = this.templatesUrl;
        if (templateid) {
            wtUrl = wtUrl + templateid;
        }
        // Send the request to the Wave Template endpoint
        const response = await this.connection.request({
            method: 'GET',
            url: wtUrl
        });
        if (response) {
            if (templateid) {
                this._template = response;
            }
            else {
                this._templates = response.templates;
            }
        }
        else {
        }
    }
    async deleteTemplate(templateid) {
        let wtUrl = this.templatesUrl;
        if (templateid) {
            wtUrl = wtUrl + templateid;
        }
        await this.connection.request({
            method: 'DELETE',
            url: wtUrl
        });
        this._id = templateid;
    }
    createError(response) {
        // For Gacks, the error message is on response.body[0].message but for handled errors
        // the error message is on response.body.Errors[0].description.
        const errMessage = _.get(response, 'Errors[0].description') || _.get(response, '[0].message') || 'Unknown Error';
        throw new Error(errMessage);
    }
}
exports.default = WaveTemplate;
//# sourceMappingURL=wavetemplate.js.map